@@ -1,4 +1,4 @@
-# Copyright 2012 Dusty Phillips
+# Copyright 2012-2013 Dusty Phillips
 
 # This file is part of gitifyhg.
 
@@ -322,13 +322,12 @@ def test_push_two_commits(git_dir, hg_repo):
     assert_hg_count(3)
 
 
-@pytest.mark.xfail
 def test_push_new_bookmark(git_dir, hg_repo):
     git_repo = clone_repo(git_dir, hg_repo)
     sh.cd(git_repo)
     sh.git.checkout("-b", "anewbranch")
     make_git_commit("b")
-    sh.git.push('--set-upstream', 'origin', 'anewbranch')
+    print sh.git.push('--set-upstream', 'origin', 'anewbranch').stderr
 
     sh.cd(hg_repo)
     assert_hg_count(2)
@@ -336,10 +335,6 @@ def test_push_new_bookmark(git_dir, hg_repo):
     sh.hg.update("anewbranch")
     assert "anewbranch" in sh.hg.tip().stdout
 
-    # TODO: Currently, it does not create a new bookmark when trying to push to
-    # a branch other than master or one named branches/<name>, which is supposed
-    # to create a named branch. This needs to be fixed.
-
 
 def test_push_tag(git_dir, hg_repo):
     git_repo = clone_repo(git_dir, hg_repo)
@@ -367,6 +362,25 @@ def test_push_tag_with_subsequent_commits(git_dir, hg_repo):
         'b', 'a'])
 
 
+def test_push_tag_with_previous_commits(git_dir, hg_repo):
+    sh.cd(hg_repo)
+    hgsha1 = sh.hg.id(id=True).stdout.strip()
+    sh.hg.tag("an_old_tag")
+    git_repo = clone_repo(git_dir, hg_repo)
+    sh.cd(git_repo)
+    make_git_commit("b")
+    sh.git.tag("this_is_a_tag")
+    sh.git.push("origin", "HEAD", tags=True, _err=sys.stderr)
+
+    sh.cd(hg_repo)
+    assert "this_is_a_tag" in sh.hg.tags().stdout
+    assert_hg_count(4)
+    sh.hg.update(2)
+    hgsha = sh.hg.id(id=True).stdout.strip()
+    assert_hg_messages(['Added tag this_is_a_tag for changeset %s' % hgsha,
+        'b', 'Added tag an_old_tag for changeset %s' % hgsha1, 'a'])
+
+
 def test_push_messaged_tag(git_dir, hg_repo):
     git_repo = clone_repo(git_dir, hg_repo)
     sh.cd(git_repo)
@@ -417,3 +431,14 @@ def test_push_only_new_tag(git_dir, hg_repo):
     sh.cd(hg_repo)
     assert "this_is_a_tag" in sh.hg.tags().stdout
     assert_hg_count(3)
+
+
+def test_push_after_rm_file_with_spaces(git_dir, hg_repo):
+    git_repo = clone_repo(git_dir, hg_repo)
+    sh.cd(git_repo)
+    make_git_commit("a", filename="name with spaces")
+
+    sh.git.rm("name with spaces")
+    sh.git.commit(message="b")
+
+    sh.git.push()
